Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1083)

Unified Diff: tools/gn/function_toolchain.cc

Issue 1606553002: Add support for Mac/iOS application bundles to GN tool. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Add unit tests & support for bundle_data_filter Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/gn/function_forward_variables_from.cc ('k') | tools/gn/functions.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gn/function_toolchain.cc
diff --git a/tools/gn/function_toolchain.cc b/tools/gn/function_toolchain.cc
index 58532551d4f2d65250db6002fbaf675eec20cff7..514d599a5be4e673ba3b0fae9693ce2bcc4621b4 100644
--- a/tools/gn/function_toolchain.cc
+++ b/tools/gn/function_toolchain.cc
@@ -809,7 +809,8 @@ Value RunTool(Scope* scope,
} else if (IsLinkerTool(tool_type)) {
subst_validator = &IsValidLinkerSubstitution;
subst_output_validator = &IsValidLinkerOutputsSubstitution;
- } else if (tool_type == Toolchain::TYPE_COPY) {
+ } else if (tool_type == Toolchain::TYPE_COPY ||
+ tool_type == Toolchain::TYPE_COPY_BUNDLE_DATA) {
subst_validator = &IsValidCopySubstitution;
subst_output_validator = &IsValidCopySubstitution;
} else {
@@ -846,9 +847,11 @@ Value RunTool(Scope* scope,
return Value();
}
- if (tool_type != Toolchain::TYPE_COPY && tool_type != Toolchain::TYPE_STAMP) {
- // All tools except the copy and stamp tools should have outputs. The copy
- // and stamp tool's outputs are generated internally.
+ if (tool_type != Toolchain::TYPE_COPY &&
+ tool_type != Toolchain::TYPE_COPY_BUNDLE_DATA &&
+ tool_type != Toolchain::TYPE_STAMP) {
+ // All tools except the copy, copy bundle data and stamp tools should have
+ // outputs. The copy and stamp tool's outputs are generated internally.
if (!ReadOutputs(&block_scope, function, subst_output_validator,
tool.get(), err))
return Value();
« no previous file with comments | « tools/gn/function_forward_variables_from.cc ('k') | tools/gn/functions.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698